==> haskell-network2.8-2.8.0.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network2.8.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network
version:              2.8.0.1
visibility:           public
id:                   network-2.8.0.1-9PNAAooCSq9HXbjyZAisWY
key:                  network-2.8.0.1-9PNAAooCSq9HXbjyZAisWY
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto, Evan Borden
homepage:             https://github.com/haskell/network
synopsis:             Low-level networking interface
description:
    This package provides a low-level networking interface.

    In network-2.6 the @Network.URI@ module was split off into its own
    package, network-uri-2.6. If you'\''re using the @Network.URI@ module
    you can automatically get it from the right package by adding this
    to your .cabal file:

    > library
    >   build-depends: network-uri-flag

category:             Network
abi:                  53d20e63e9b2c552c33b3835b6d1ba68
exposed:              True
exposed-modules:
    Network Network.BSD Network.Socket Network.Socket.ByteString
    Network.Socket.ByteString.Lazy Network.Socket.Internal

hidden-modules:
    Network.Socket.ByteString.Internal Network.Socket.Types
    Network.Socket.ByteString.IOVec
    Network.Socket.ByteString.Lazy.Posix
    Network.Socket.ByteString.MsgHdr

import-dirs:          /usr/lib/ghc-8.10.1/site-local/network-2.8.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/network-2.8.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/network-2.8.0.1
hs-libraries:         HSnetwork-2.8.0.1-9PNAAooCSq9HXbjyZAisWY
include-dirs:         /usr/lib/ghc-8.10.1/site-local/network-2.8.0.1/include
includes:             HsNet.h HsNetDef.h
depends:              base-4.14.0.0 bytestring-0.10.10.0 unix-2.7.2.2
ld-options:           "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces:   /usr/share/doc/haskell-network2.8/html/network.haddock
haddock-html:         /usr/share/doc/haskell-network2.8/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network2.8-2.8.0.1-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network2.8.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network
version:              2.8.0.1
visibility:           public
id:                   network-2.8.0.1-4Y2Zlqt2kImIDU3SGPyhtY
key:                  network-2.8.0.1-4Y2Zlqt2kImIDU3SGPyhtY
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto, Evan Borden
homepage:             https://github.com/haskell/network
synopsis:             Low-level networking interface
description:
    This package provides a low-level networking interface.

    In network-2.6 the @Network.URI@ module was split off into its own
    package, network-uri-2.6. If you'\''re using the @Network.URI@ module
    you can automatically get it from the right package by adding this
    to your .cabal file:

    > library
    >   build-depends: network-uri-flag

category:             Network
abi:                  86d636b582010838b4580ef390c90360
exposed:              True
exposed-modules:
    Network Network.BSD Network.Socket Network.Socket.ByteString
    Network.Socket.ByteString.Lazy Network.Socket.Internal

hidden-modules:
    Network.Socket.ByteString.Internal Network.Socket.Types
    Network.Socket.ByteString.IOVec
    Network.Socket.ByteString.Lazy.Posix
    Network.Socket.ByteString.MsgHdr

import-dirs:          /usr/lib/ghc-8.10.1/site-local/network-2.8.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/network-2.8.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/network-2.8.0.1
hs-libraries:         HSnetwork-2.8.0.1-4Y2Zlqt2kImIDU3SGPyhtY
include-dirs:         /usr/lib/ghc-8.10.1/site-local/network-2.8.0.1/include
includes:             HsNet.h HsNetDef.h
depends:              base-4.14.0.0 bytestring-0.10.10.0 unix-2.7.2.2
ld-options:           "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces:   /usr/share/doc/haskell-network2.8/html/network.haddock
haddock-html:         /usr/share/doc/haskell-network2.8/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
